## Shopping attitudes

### Description

20 consumers were asked to respond to six questions to determine their attitudes towards shopping.

### Variables

A data frame with 20 observations on 7 variable. The scores shown for variables v1-v6 indicate the level of agreement with the statement on a 7-point scale where 1 = strongly disagree and 7 = strongly agree.

- id = Respondent id
- v1 = "Shopping is fun"
- v2 = "Shopping is bad for your budget"
- v3 = "I combine shopping with eating out"
- v4 = "I try to get the best buys while shopping"
- v5 = "I don't care about shopping"
- v6 = "You can save a lot of money by comparing prices"